==> siskin-0.123.0.tar.gz: siskin-0.123.0/siskin/cacheutils.py <==
# coding: utf-8
# pylint: disable=F0401,C0111,W0232,E1101,E1103,C0301,C0103,W0614,W0401

# Copyright 2015 by Leipzig University Library, http://ub.uni-leipzig.de
#                   The Finc Authors, http://finc.info
#                   Martin Czygan, <martin.czygan@uni-leipzig.de>
#
# This file is part of some open source application.
#
# Some open source application is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, either
# version 3 of the License, or (at your option) any later version.
#
# Some open source application is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
#
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>
"""
Module exists, so we do not have to do star (*) imports in utils.py.
"""

import json

from luigi.task import Register
from siskin.sources import *
from siskin.workflows import *


def _write_task_import_cache(path):
    """
    Write dictionary of task name module name mappings to given path.
    """
    with open(path, 'w') as output:
        task_import_cache = dict([(name, Register.get_task_cls(name).__module__) for name in Register.task_names() if name[0].isupper()])
        json.dump(task_import_cache, output)

==> siskin-1.3.1.tar.gz: siskin-1.3.1/siskin/cacheutils.py <==
# coding: utf-8
# pylint: disable=F0401,C0111,W0232,E1101,E1103,C0301,C0103,W0614,W0401

# Copyright 2015 by Leipzig University Library, http://ub.uni-leipzig.de
#                   The Finc Authors, http://finc.info
#                   Martin Czygan, <martin.czygan@uni-leipzig.de>
#
# This file is part of some open source application.
#
# Some open source application is free software: you can redistribute
# it and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation, either
# version 3 of the License, or (at your option) any later version.
#
# Some open source application is distributed in the hope that it will
# be useful, but WITHOUT ANY WARRANTY; without even the implied warranty
# of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
#
# @license GPL-3.0+ <http://spdx.org/licenses/GPL-3.0+>
"""
Module exists, so we do not have to do star (*) imports in utils.py.
"""

import json

from luigi.task import Register
from siskin.sources import *
from siskin.workflows import *


def _write_task_import_cache(path):
    """
    Write dictionary of task name module name mappings to given path.
    """
    with open(path, "w") as output:
        task_import_cache = dict(
            [
                (name, Register.get_task_cls(name).__module__)
                for name in Register.task_names()
                if name[0].isupper()
            ]
        )
        json.dump(task_import_cache, output)
